import React from "react";
import { Link } from "@components/Link";

export interface BreadcrumbsProps {
  crumbs?: Array<{
    target?: string;
    title?: string;
    icon?: React.ReactElement;
  }>;
  className?: string;
}
export const Breadcrumbs: React.FC<BreadcrumbsProps> = ({ crumbs, className }) => {
  return crumbs && crumbs.length ? (
    <div className={`inline-flex ${className || ""}`}>
      {crumbs.map((crumb, index) => (
        <div
          className={`${
            index === crumbs.length - 1
              ? "font-inter font-medium"
              : "font-flex font-normal"
          } flex text-sm leading-5 text-grey-500`}
          key={"breadcrumb" + index}
        >
          {(crumb.icon || crumb.title) && (
            <Link
              to={crumb.target}
              className={`flex-shrink-0 !flex gap-2 items-center ${
                crumb.target
                  ? "hover:multi-line-underline multi-line-grey-500 !w-auto"
                  : ""
              }`}
            >
              {crumb.icon || ""}
              {crumb.title || ""}
            </Link>
          )}
          {!crumb.icon && !crumb.title && "Unknown"}
          {index !== crumbs.length - 1 && (
            <div className="font-flex text-sm leading-5 font-normal text-grey-500 px-2">
              /
            </div>
          )}
        </div>
      ))}
    </div>
  ) : null;
};
