import React from "react";
import { Link } from "@components/Link";
import { IMobileMenu } from "@interfaces/IHeader";

export const MobileMenu: React.FC<IMobileMenu> = ({ isMobileOpen, data }) => {
  return (
    <div
      className={`absolute no-scrollbar left-1/2 -translate-x-1/2 container lg:hidden pt-10 overflow-y-scroll h-full pb-48 transition-opacity ease-out duration-500 delay-300 opacity-0 ${
        isMobileOpen ? "opacity-100 translate-y-0" : "translate-y-[-9999px]"
      }`}
    >
      <div className="w-full flex flex-col md:flex-row md:flex-wrap font-plex">
        {data.map((submenu, index) => (
          <div
            key={index}
            className="w-full md:w-1/3 lg:w-1/5 md:mt-0 mb-16 md:mb-8 lg:mb-0"
          >
            {submenu.children && submenu.children.length > 0 ? (
              <h5 className="w-fit text-sm leading-5 font-semibold text-grey-50">
                {submenu.title}
              </h5>
            ) : (
              <Link
                to={submenu.target}
                className="w-fit text-sm leading-5 font-semibold text-grey-50"
              >
                {submenu.title}
              </Link>
            )}
            {submenu.children && submenu.children.length > 0 && (
              <ul>
                {submenu.children.map((child, index) => (
                  <li key={index} className="w-fit mt-5">
                    <Link
                      to={child.target}
                      className="text-sm leading-5 font-normal text-grey-400"
                    >
                      {child.title}
                    </Link>
                  </li>
                ))}
              </ul>
            )}
          </div>
        ))}
      </div>
    </div>
  );
};
