import React, { useState } from "react";
import { YoutubeEmbed } from "@components/YoutubeEmbed";
import { useKeenSlider } from "keen-slider/react";

export interface VideoSliderProps {
  videos: string[];
  className?: string;
  title?: string;
}

export const VideoSlider: React.FC<VideoSliderProps> = ({ videos, className, title }) => {
  const initialSlideIndex = 0;

  const [, setCurrentIndex] = useState(initialSlideIndex);
  const [sliderRef, instanceRef] = useKeenSlider({
    selector: ".slide",
    loop: true,
    initial: initialSlideIndex,
    slides: {
      perView: "auto",
      spacing: 8,
      origin: "center",
    },
    slideChanged(e) {
      setCurrentIndex(e.track.details.rel);
    },
  });

  return (
    <>
      {title && (
        <div className="container">
          <h3 className="font-inter sm:font-karla text-3xl md:text-5xl leading-9 md:leading-none font-normal text-grey-900 mb-6 md:mb-8">
            {title}
          </h3>
        </div>
      )}

      <div className={`overflow-x-hidden py-8 ${className || ""}`}>
        <div ref={sliderRef} className="flex w-full">
          {videos &&
            videos.map((video, index) => (
              <YoutubeEmbed
                className="slide"
                key={video}
                embedId={video}
                onFirstClick={() => {
                  setCurrentIndex(index);
                  instanceRef?.current?.moveToIdx(index);
                }}
              />
            ))}
        </div>
      </div>
    </>
  );
};
